﻿#if !PORTABLE && !NETSTANDARD1_2
using System;
using System.IO;

namespace Exceptionless.Utility {
    public static class PathHelper {
        private const string DATA_DIRECTORY = "|DataDirectory|";

        /// <summary>
        /// Expand the filename of the data source, resolving the |DataDirectory| macro as appropriate.
        /// </summary>
        /// <remarks>
        /// Expanding of the |DataDirectory| will only happen if access to AppDomain data is available.
        /// </remarks>
        /// <param name="sourceFile">The database filename to expand</param>
        /// <returns>The expanded path and filename of the filename</returns>
        public static string ExpandPath(string sourceFile) {
            if (String.IsNullOrEmpty(sourceFile))
                return sourceFile;

            if (!sourceFile.StartsWith(DATA_DIRECTORY, StringComparison.OrdinalIgnoreCase))
                return Path.GetFullPath(sourceFile);

#if !(PORTABLE || NETSTANDARD1_0 || NETSTANDARD1_1 || NETSTANDARD1_2 || NETSTANDARD1_3 || NETSTANDARD1_4)
            string dataDirectory = GetDataDirectory();
            int length = DATA_DIRECTORY.Length;

            if (sourceFile.Length <= length)
                return dataDirectory;

            string path = sourceFile.Substring(length);
            char c = path[0];

            if (c == Path.DirectorySeparatorChar || c == Path.AltDirectorySeparatorChar)
                path = path.Substring(1);

            string fullPath = Path.Combine(dataDirectory, path);
            fullPath = Path.GetFullPath(fullPath);

            return fullPath;
#else
            return sourceFile;
#endif
        }

#if !(PORTABLE || NETSTANDARD1_0 || NETSTANDARD1_1 || NETSTANDARD1_2)
        /// <summary>
        /// Gets the data directory for the |DataDirectory| macro.
        /// </summary>
        /// <returns>The DataDirectory path.</returns>
        public static string GetDataDirectory() {
            string dataDirectory = AppDomain.CurrentDomain.GetData("DataDirectory") as string;
            if (String.IsNullOrEmpty(dataDirectory))
                dataDirectory = AppDomain.CurrentDomain.BaseDirectory;

            return Path.GetFullPath(dataDirectory);
        }
#endif
    }
}
#endif